@@ -81,6 +81,9 @@ def get_parser():
     parser.add_argument(
         "-L", "--dfl_lvl", "--dfl", "--deflate",
         help="Lempel-Ziv deflation/compression (lvl=0..9) for netCDF4 output", default=0, type=int)
+    parser.add_argument(
+        "--merra",
+        help="MERRA", action="store_true")
 
     '''
     
